kallisto on a set of FASTQ
files. Requires kallisto (http://pachterlab.github.io/kallisto/)
to be installed and a kallisto feature index must have been generated prior
to using this function. See the kallisto website for installation and basic
usage instructions.
runKallisto(targets_file, transcript_index, single_end = TRUE, output_prefix = "output", fragment_length = NULL, fragment_standard_deviation = NULL, n_cores = 2, n_bootstrap_samples = 0, bootstrap_seed = NULL, correct_bias = TRUE, plaintext = FALSE, kallisto_version = "current", verbose = TRUE, dry_run = FALSE, kallisto_cmd = "kallisto")"output" and
the sample name (column 1 of targets_file) is appended (preceded by an
underscore).single_end is TRUE,
optional if FALSE (kallisto default for paired-end data is that the
value is estimated from the input data).single_end is TRUE, optional if FALSE (kallisto default
for paired-end data is that the value is estimated from the input data).parallel is used. Default is 2 cores.TRUE then bootstrapping results are
returned in a plain text file rather than an HDF5
https://www.hdfgroup.org/HDF5/ file."pre-0.42.2" or "current".
This is required because the kallisto developers changed the output file
extensions and added features in version 0.42.2.TRUE then a list containing the kallisto
commands that would be run and the output directories is returned. Can be
used to read in results if kallisto is run outside an R session or to produce
a script to run outside of an R session.kallisto_call, the call used for
kallisto, (2) kallisto_log the log generated by kallisto, and (3)
output_dir the directory in which the kallisto results can be found.
kallisto index [arguments] FASTA-file. See the kallisto documentation
for further details.
## Not run:
# ## If in kallisto's 'test' directory, then try these calls:
# ## Generate 'targets.txt' file:
# write.table(data.frame(Sample="sample1", File1="reads_1.fastq.gz", File2="reads_1.fastq.gz"),
# file="targets.txt", quote=FALSE, row.names=FALSE, sep="\t")
# kallisto_log <- runKallisto("targets.txt", "transcripts.idx", single_end=FALSE,
# output_prefix="output", verbose=TRUE, n_bootstrap_samples=10,
# dry_run = FALSE)
# ## End(Not run)
Run the code above in your browser using DataLab